@@ -5,19 +5,16 @@ import os
 from collections import namedtuple
 from logging import getLogger
 
-import OpenSSL
 import boto3
 import botocore.exceptions
+import OpenSSL
 from boto3.exceptions import RetriesExceededError, S3UploadFailedError
 from boto3.s3.transfer import TransferConfig
 from botocore.client import Config
 
 from .compat import TO_UNICODE
-from .constants import (
-    SHA256_DIGEST, ResultStatus, FileHeader,
-    HTTP_HEADER_CONTENT_TYPE,
-    HTTP_HEADER_VALUE_OCTET_STREAM)
-from .encryption_util import (EncryptionMetadata)
+from .constants import HTTP_HEADER_CONTENT_TYPE, HTTP_HEADER_VALUE_OCTET_STREAM, SHA256_DIGEST, FileHeader, ResultStatus
+from .encryption_util import EncryptionMetadata
 
 SFC_DIGEST = u'sfc-digest'
 
@@ -44,8 +41,8 @@ class SnowflakeS3Util:
     """
     S3 Utility class
     """
-    # magic number, given from the AWS error message.
-    DATA_SIZE_THRESHOLD = 5242880
+    # magic number, given from  error message.
+    DATA_SIZE_THRESHOLD = 67108864
 
     @staticmethod
     def create_client(stage_info, use_accelerate_endpoint=False):
@@ -58,7 +55,11 @@ class SnowflakeS3Util:
         logger = getLogger(__name__)
         stage_credentials = stage_info[u'creds']
         security_token = stage_credentials.get(u'AWS_TOKEN', None)
-        logger.debug(u"AWS_ID: %s", stage_credentials[u'AWS_ID'])
+        end_point = stage_info['endPoint']
+        logger.debug(u"AWS_KEY_ID: %s", stage_credentials[u'AWS_KEY_ID'])
+
+        # if GS sends us an endpoint, it's likely for FIPS. Use it.
+        end_point = (u'https://' + stage_info['endPoint']) if stage_info['endPoint'] else None
 
         config = Config(
             signature_version=u's3v4',
@@ -69,9 +70,10 @@ class SnowflakeS3Util:
         client = boto3.resource(
             u's3',
             region_name=stage_info['region'],
-            aws_access_key_id=stage_credentials[u'AWS_ID'],
-            aws_secret_access_key=stage_credentials[u'AWS_KEY'],
+            aws_access_key_id=stage_credentials[u'AWS_KEY_ID'],
+            aws_secret_access_key=stage_credentials[u'AWS_SECRET_KEY'],
             aws_session_token=security_token,
+            endpoint_url=end_point,
             config=config,
         )
         return client
@@ -194,7 +196,8 @@ class SnowflakeS3Util:
                 Callback=meta[u'put_callback'](
                     data_file,
                     os.path.getsize(data_file),
-                    output_stream=meta[u'put_callback_output_stream']) if
+                    output_stream=meta[u'put_callback_output_stream'],
+                    show_progress_bar=meta[u'show_progress_bar']) if
                 meta[u'put_callback'] else None,
                 ExtraArgs={
                     u'Metadata': s3_metadata,
@@ -253,7 +256,8 @@ class SnowflakeS3Util:
                 Callback=meta[u'get_callback'](
                     meta[u'src_file_name'],
                     meta[u'src_file_size'],
-                    output_stream=meta[u'get_callback_output_stream']) if
+                    output_stream=meta[u'get_callback_output_stream'],
+                    show_progress_bar=meta[u'show_progress_bar']) if
                 meta[u'get_callback'] else None,
                 Config=TransferConfig(
                     multipart_threshold=SnowflakeS3Util.DATA_SIZE_THRESHOLD,
